@@ -1,4 +1,4 @@
 #! /usr/bin/env bash
 $EXTRACTRC `find . -name \*.ui -o -name \*.rc -o -name \*.kcfg` >> rc.cpp
-$XGETTEXT `find . -name \*.cpp` -o $podir/kommit.pot
+$XGETTEXT `find . -name \*.h -o -name \*.cpp` -o $podir/kommit.pot
 rm -f rc.cpp
