@@ -13,6 +13,10 @@ class OverlayTest : public QObject
     Q_OBJECT
 
 private Q_SLOTS:
+    void initTestCase();
+
     void test1();
     void checkRootDir();
+    void dirTest();
+    void invalidDir();
 };
