@@ -7,7 +7,6 @@ SPDX-License-Identifier: GPL-3.0-or-later
 // application header
 #include "commandargsparser.h"
 #include "config-kommit.h"
-#include "dialogs/changedfilesdialog.h"
 
 // KF headers
 #include <KAboutData>
@@ -34,6 +33,8 @@ SPDX-License-Identifier: GPL-3.0-or-later
 
 int main(int argc, char **argv)
 {
+    qputenv("GIT_TRACE", "1");
+
 #if HAVE_KICONTHEME && (KICONTHEMES_VERSION >= QT_VERSION_CHECK(6, 3, 0))
     KIconTheme::initTheme();
 #endif
@@ -44,7 +45,6 @@ int main(int argc, char **argv)
     QApplication application(argc, argv);
 
     KLocalizedString::setApplicationDomain("kommit");
-    KCrash::initialize();
 #if HAVE_STYLE_MANAGER
     KStyleManager::initStyle();
 #else // !HAVE_STYLE_MANAGER
@@ -64,6 +64,7 @@ int main(int argc, char **argv)
     aboutData.setDesktopFileName(QStringLiteral("org.kde.kommit"));
 
     KAboutData::setApplicationData(aboutData);
+    KCrash::initialize();
     application.setWindowIcon(QIcon::fromTheme(QStringLiteral("kommit")));
 
     QCommandLineParser parser;
