@@ -15,7 +15,6 @@ class QLabel;
 class RepositoryData;
 namespace Git
 {
-class Manager;
 }
 /**
  * This class serves as the main window for kommit.  It handles the
@@ -37,6 +36,7 @@ public:
 
 private:
     void gitPathChanged();
+    void gitCurrentBranchChanged();
     void settingsUpdated();
     void repoStatus();
     void initRepo();
@@ -54,6 +54,7 @@ private:
     void merge();
     void cleanup();
     void initActions();
+    void changeLogs();
     void initRecentRepos(const QString &newItem = QString());
 
     template<class T>
@@ -61,7 +62,6 @@ private:
     void init();
     void updateActions(bool enabled);
 
-    Git::Manager *mGit = nullptr;
     RepositoryData *mGitData{nullptr};
 
     QAction *mRecentAction = nullptr;
@@ -83,4 +83,5 @@ private:
     QAction *mRepoSettingsAction = nullptr;
     QAction *mRepoSwitchAction = nullptr;
     QAction *mRepoDiffTreeAction = nullptr;
+    QAction *mChangeLogsAction = nullptr;
 };
