@@ -10,7 +10,7 @@ SPDX-License-Identifier: GPL-3.0-or-later
 
 namespace Git
 {
-class Manager;
+class Repository;
 };
 
 class FileTest : public QObject
@@ -31,7 +31,7 @@ private Q_SLOTS:
     void checkContentInBranch();
 
 private:
-    Git::Manager *mManager;
+    Git::Repository *mManager;
 
     QString mFileContentAtFirstCommit;
     QString mFileContentAtSecondCommit;
