@@ -8,29 +8,30 @@ SPDX-License-Identifier: GPL-3.0-or-later
 #include "libkommit_export.h"
 #include <QList>
 #include <QMap>
+#include <entities/commit.h>
 
 namespace Git
 {
 
-class Manager;
+class Repository;
 class Commit;
+// TODO: remove this class
 class LIBKOMMIT_EXPORT LogList : public QList<Commit *>
 {
 public:
     LogList();
     explicit LogList(QString branch);
 
-    void load(Git::Manager *git);
+    void load(Git::Repository *git);
     void initGraph();
 
-    Q_REQUIRED_RESULT const QString &branch() const;
+    [[nodiscard]] const QString &branch() const;
     void setBranch(const QString &newBranch);
 
     Commit *findByHash(const QString &hash, int *index = nullptr) const;
 
 private:
-    Q_REQUIRED_RESULT LIBKOMMIT_NO_EXPORT QString branchName(const QString &refLog);
-    LIBKOMMIT_NO_EXPORT void initChilds();
+    [[nodiscard]] LIBKOMMIT_NO_EXPORT QString branchName(const QString &refLog);
     QString mBranch;
     QStringList mBranches;
     QMap<QString, Commit *> mDataByCommitHashLong;
