@@ -9,16 +9,21 @@ SPDX-License-Identifier: GPL-3.0-or-later
 #include "abstractactions.h"
 #include "libkommitwidgets_export.h"
 
+#include <Kommit/Remote>
+
 class LIBKOMMITWIDGETS_EXPORT RemotesActions : public AbstractActions
 {
     Q_OBJECT
 
 public:
-    explicit RemotesActions(Git::Manager *git, QWidget *parent = nullptr);
+    explicit RemotesActions(Git::Repository *git, QWidget *parent = nullptr);
 
-    Q_REQUIRED_RESULT const QString &remoteName() const;
+    [[nodiscard]] const QString &remoteName() const;
     void setRemoteName(const QString &newRemoteName);
 
+    [[nodiscard]] const Git::Remote &remote() const;
+    void setRemote(const Git::Remote &newRemote);
+
 private:
     LIBKOMMITWIDGETS_NO_EXPORT void create();
     LIBKOMMITWIDGETS_NO_EXPORT void remove();
@@ -30,5 +35,7 @@ private:
     DEFINE_ACTION(actionRename)
     DEFINE_ACTION(actionUpdate)
     DEFINE_ACTION(actionChangeUrl)
+
     QString mRemoteName;
+    Git::Remote mRemote;
 };
