@@ -16,11 +16,10 @@ class LIBKOMMITWIDGETS_EXPORT ChangedSubmodulesDialog : public AppDialog, privat
     Q_OBJECT
 
 public:
-    explicit ChangedSubmodulesDialog(Git::Manager *git, QWidget *parent = nullptr);
+    explicit ChangedSubmodulesDialog(Git::Repository *git, QWidget *parent = nullptr);
 
 private:
-    LIBKOMMITWIDGETS_NO_EXPORT void slotComitPushButtonClicked();
+    LIBKOMMITWIDGETS_NO_EXPORT void slotComitPushButtonClicked(const QString &moduleName);
     LIBKOMMITWIDGETS_NO_EXPORT void reload();
     ChangedFilesModel *mModel = nullptr;
-    QMap<QPushButton *, QString> mButtonsMap;
 };
