@@ -10,12 +10,13 @@ SPDX-License-Identifier: GPL-3.0-or-later
 #include "libkommitwidgets_export.h"
 #include "ui_filestreedialog.h"
 
+#include <Kommit/Tree>
+
 namespace Git
 {
-class Manager;
-class Tree;
+class Repository;
 class ITree;
-};
+}
 
 class FileActions;
 class TreeModel;
@@ -24,17 +25,21 @@ class LIBKOMMITWIDGETS_EXPORT FilesTreeDialog : public AppDialog, private Ui::Fi
     Q_OBJECT
 
 public:
-    FilesTreeDialog(Git::Manager *git, const QString &place, QWidget *parent = nullptr);
-    // FilesTreeDialog(Git::Manager *git, QSharedPointer<Git::Tree> tree, QWidget *parent = nullptr);
-    FilesTreeDialog(Git::Manager *git, QSharedPointer<Git::ITree> tree, QWidget *parent = nullptr);
+    FilesTreeDialog(Git::Repository *git, const QString &place, QWidget *parent = nullptr);
+    FilesTreeDialog(Git::Repository *git, Git::ITree *tree, QWidget *parent = nullptr);
 
 private:
+    LIBKOMMITWIDGETS_NO_EXPORT void slotTreeViewCustomContextMenuRequested(const QPoint &pos);
     LIBKOMMITWIDGETS_NO_EXPORT void slotListWidgetCustomContextMenuRequested(const QPoint &pos);
     LIBKOMMITWIDGETS_NO_EXPORT void slotTreeViewClicked(const QModelIndex &index);
-    LIBKOMMITWIDGETS_NO_EXPORT void initModel(const QStringList &files);
+    LIBKOMMITWIDGETS_NO_EXPORT void slotExtract();
+    // LIBKOMMITWIDGETS_NO_EXPORT void initModel(const QStringList &files);
+    LIBKOMMITWIDGETS_NO_EXPORT void initModel(const Git::Tree &tree);
+
     TreeModel *const mTreeModel;
     const QString mPlace;
     FileActions *const mActions;
-
-    QSharedPointer<Git::Tree> mTree;
+    Git::Tree mTree;
+    QMenu *const mTreeViewMenu;
+    QString mExtractPrefix;
 };
