@@ -13,28 +13,28 @@ SPDX-License-Identifier: GPL-3.0-or-later
 namespace Git
 {
 class AddSubmoduleCommand;
-class Manager;
+class Repository;
 }
 class LIBKOMMITWIDGETS_EXPORT SubmoduleInfoDialog : public AppDialog, private Ui::SubmoduleInfoDialog
 {
     Q_OBJECT
 
 public:
-    explicit SubmoduleInfoDialog(Git::Manager *git, QWidget *parent = nullptr);
+    explicit SubmoduleInfoDialog(Git::Repository *git, QWidget *parent = nullptr);
 
-    Q_REQUIRED_RESULT bool force() const;
+    [[nodiscard]] bool force() const;
     void setForce(bool newForce);
 
-    Q_REQUIRED_RESULT QString url() const;
+    [[nodiscard]] QString url() const;
     void setUrl(const QString &newUrl);
 
-    Q_REQUIRED_RESULT QString path() const;
+    [[nodiscard]] QString path() const;
     void setPath(const QString &newPath);
 
-    Q_REQUIRED_RESULT QString branch() const;
+    [[nodiscard]] QString branch() const;
     void setBranch(const QString &newBranch);
 
-    Q_REQUIRED_RESULT Git::AddSubmoduleCommand *command() const;
+    [[nodiscard]] Git::AddSubmoduleCommand *command() const;
 
 private:
     LIBKOMMITWIDGETS_NO_EXPORT void slotLineEditPathUrlSelected(const QUrl &url);
