@@ -6,12 +6,13 @@ SPDX-License-Identifier: GPL-3.0-or-later
 
 #pragma once
 
-#include "filestatus.h"
+#include <Kommit/FileStatus>
 #include <diff.h>
 #define TREEMODEL_NODE_DATA_TYPE Diff::DiffType
 #include "treemodel.h"
 #include <entities/treediff.h>
 
+class TreeNode;
 class DiffTreeModel : public TreeModel
 {
     Q_OBJECT
@@ -23,12 +24,13 @@ public:
     void addFile(const QString &file, Diff::DiffType type);
     void addFile(const Git::TreeDiffEntry &diffEntry);
 
-    QVariant data(const QModelIndex &index, int role) const override;
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role) const override;
 
     void emitAll();
 
 private:
-    Q_REQUIRED_RESULT Diff::DiffType toDiffType(Git::FileStatus::Status status) const;
-    Q_REQUIRED_RESULT Diff::DiffType toDiffType(Git::ChangeStatus status) const;
-    Node *createPath(const QStringList &path, Diff::DiffType status);
+    [[nodiscard]] Diff::DiffType toDiffType(Git::FileStatus::Status status) const;
+    [[nodiscard]] Diff::DiffType toDiffType(Git::ChangeStatus status) const;
+    TreeNode *createPath(const QStringList &path, Diff::DiffType status);
+    Diff::DiffType calculateNodeType(TreeNode *node) const;
 };
